@@ -64,7 +64,9 @@ def dump_json(p, j, exist_ok=False, override=False):
 def ensure_config(path):
     config_path = os.path.join(path, "config.json")
     if not os.path.exists(config_path):
-        node = {"keywords": []}
+        node = {"keywords": [],
+                "keywords_must": [],
+                "keywords_forbid": []}
         dump_json(config_path, node, exist_ok=True, override=False)
         return node
     else:
@@ -121,7 +123,7 @@ class TreeWalker:
         root = self.load_root()
         root_node = {
             "node_id": root["node_id"],
-            "keywords": root["keywords"],
+            "keywords": root.get("keywords", []),
             "children": [],
             "keywords_must": root.get("keywords_must", []),
             "keywords_forbid": root.get("keywords_forbid", [])
@@ -282,7 +284,9 @@ class TreeWalker:
                 "node_id": self.gen_node_id(),
                 "keywords": [],
                 "children": [],
-                "export": []
+                "export": [],
+                "keywords_must": [],
+                "keywords_forbid": []
             }
             dump_json(config_path, config, exist_ok=True, override=True)
         else:
@@ -343,7 +347,7 @@ class TreeWalker:
         result = {
             name: {
                 "node_id": config["node_id"],
-                "keywords": config["keywords"],
+                "keywords": config.get("keywords", []),
                 "children": config.get("children", []),
                 "keywords_must": config.get("keywords_must", []),
                 "keywords_forbid": config.get("keywords_forbid", [])
